@@ -9,7 +9,6 @@ import re
 import subprocess  # nosec
 import sys
 import textwrap
-import warnings
 from datetime import datetime
 from pathlib import Path
 from pprint import pformat
@@ -104,18 +103,6 @@ def get_all_tags(sort_by: str = DEFAULT_SORT_BY, root: str | os.PathLike | None
     return []
 
 
-def get_branch_tags(*args, **kwargs) -> list[str]:
-    warnings.warn(
-        "`get_branch_tags` function is deprecated "
-        "since setuptools-git-versioning v1.8.0 "
-        "and will be dropped in v2.0.0\n"
-        "Please use `get_tags` instead",
-        category=UserWarning,
-    )
-
-    return get_tags(*args, **kwargs)
-
-
 def get_tags(
     sort_by: str = DEFAULT_SORT_BY,
     filter_callback: Callable[[str], str | None] | None = None,
@@ -188,7 +175,7 @@ def _read_toml(name_or_path: str | os.PathLike = "pyproject.toml", root: str | o
 
     log.log(INFO, "Trying 'pyproject.toml' ...")
     try:
-        # for Python 3.11
+        # for Python 3.11+
         import tomllib
 
         with file_path.open("rb") as file:
@@ -232,24 +219,9 @@ def _infer_setup_py(name_or_path: str = "setup.py", root: str | os.PathLike | No
         os.chdir(original_cwd)
 
 
-# TODO: remove along with version_config
-def _parse_config(dist: Distribution, attr: Any, value: Any) -> None:
-    from distutils.errors import DistutilsOptionError
-
-    if attr == "version_config" and value is not None:
-        warnings.warn(
-            "'version_config' option is deprecated "
-            "since setuptools-git-versioning v1.8.0 "
-            "and will be dropped in v2.0.0\n"
-            "Please rename it to 'setuptools_git_versioning'",
-            category=UserWarning,
-        )
-
-        if getattr(dist, "setuptools_git_versioning", None) is not None:
-            raise DistutilsOptionError(
-                "You can set either 'version_config' or 'setuptools_git_versioning' "
-                "but not both of them at the same time"
-            )
+def parse_config(dist: Distribution, attr: Any, value: Any) -> None:
+    "Dummy function used only to register in distutils"
+    return None
 
 
 def infer_version(dist: Distribution, root: str | os.PathLike | None = None) -> str | None:
@@ -257,18 +229,7 @@ def infer_version(dist: Distribution, root: str | os.PathLike | None = None) ->
 
     from distutils.errors import DistutilsOptionError, DistutilsSetupError
 
-    config = getattr(dist, "setuptools_git_versioning", None) or getattr(dist, "version_config", None)
-
-    if isinstance(config, bool):
-        warnings.warn(
-            "Passing boolean value to 'version_config'/'setuptools_git_versioning' option is deprecated "
-            "since setuptools-git-versioning 1.8.0 "
-            "and will be dropped in v2.0.0\n"
-            "Please change value to '{'enabled': False/True}'",
-            category=UserWarning,
-        )
-        config = {"enabled": config}
-
+    config = getattr(dist, "setuptools_git_versioning", None)
     toml_config = _read_toml(root=root)
 
     if config is None:
@@ -450,12 +411,12 @@ def _callable_factory(
     try:
         return _load_callable(regexp_or_ref, package_name, root=root)
     except (ImportError, NameError) as e:
-        log.warning("%s is not a valid function reference: %s", callable_name, e)
+        log.log(DEBUG, "%s is not a valid function reference: %s", callable_name, e)
 
     try:
         return callable_factory(regexp_or_ref)
     except re.error as e:
-        log.error("%s is not valid regexp: %s", callable_name, e)
+        log.error("%s is not valid regexp neither a valid function reference: %s", callable_name, e)
         raise ValueError(f"Cannot parse {callable_name}") from e
 
 
@@ -545,6 +506,9 @@ def version_from_git(
             )
         return _get_version_from_callback(version_callback, package_name, root=root)
 
+    head_sha = get_sha(root=root)
+    log.log(INFO, "HEAD SHA-256: %r", head_sha)
+
     filter_callback = None
     if tag_filter:
         filter_callback = _callable_factory(
@@ -555,16 +519,22 @@ def version_from_git(
             root=root,
         )
 
-    from_file = False
     log.log(INFO, "Getting latest tag")
     log.log(DEBUG, "Sorting tags by %r", sort_by)
     tag = get_tag(sort_by=sort_by, root=root, filter_callback=filter_callback)
+    if not tag:
+        log.log(INFO, "No tags found")
+        tag_sha = None
+        on_tag = False
+    else:
+        tag_sha = get_sha(tag, root=root)
+        log.log(INFO, "Tag SHA-256: %r", tag_sha)
 
-    if tag is None:
-        log.log(INFO, "No tag, checking for 'version_file'")
-        if version_file is None:
-            log.log(INFO, "No 'version_file' set, return starting_version %r", starting_version)
-            return _sanitize_version(starting_version)
+        on_tag = head_sha is not None and head_sha == tag_sha
+        log.log(INFO, "HEAD is tagged: %r", on_tag)
+
+    if version_file:
+        log.log(INFO, "Checking for 'version_file'")
 
         if not Path(version_file).exists():
             log.log(
@@ -573,26 +543,30 @@ def version_from_git(
                 version_file,
                 starting_version,
             )
-            return _sanitize_version(starting_version)
+            tag = None
+        else:
+            log.log(INFO, "Reading version_file '%s' content", version_file)
+            tag = _read_version_from_file(version_file, root=root) or None
 
-        log.log(INFO, "version_file '%s' does exist, reading its content", version_file)
-        from_file = True
-        tag = _read_version_from_file(version_file, root=root)
+            if not tag:
+                log.log(INFO, "File %r is empty", version_file)
+            else:
+                log.log(DEBUG, "File content: %r", tag)
+                if not count_commits_from_version_file:
+                    return _sanitize_version(tag)
 
-        if not tag:
-            log.log(INFO, "File is empty, return starting_version %r", version_file, starting_version)
-            return _sanitize_version(starting_version)
+                file_sha = get_latest_file_commit(version_file, root=root)
+                log.log(DEBUG, "File SHA-256: %r", file_sha)
 
-        log.log(DEBUG, "File content: %r", tag)
-        if not count_commits_from_version_file:
-            return _sanitize_version(tag)
+                ccount = count_since(file_sha, root=root) if file_sha is not None else None
+                log.log(INFO, "Commits count between HEAD and last version file change: %r", ccount)
 
-        tag_sha = get_latest_file_commit(version_file, root=root)
-        log.log(DEBUG, "File SHA-256: %r", tag_sha)
-    else:
-        log.log(INFO, "Latest tag: %r", tag)
-        tag_sha = get_sha(tag, root=root)
-        log.log(INFO, "Tag SHA-256: %r", tag_sha)
+    elif not head_sha:
+        log.log(INFO, "Not a git repo, or repo without any branch")
+
+    elif tag_sha:
+        ccount = count_since(tag_sha, root=root)
+        log.log(INFO, "Commits count between HEAD and last tag: %r", ccount)
 
         if tag_formatter is not None:
             tag_format_callback = _callable_factory(
@@ -606,19 +580,13 @@ def version_from_git(
             tag = tag_format_callback(tag)
             log.log(DEBUG, "Tag after formatting: %r", tag)
 
+    if not tag:
+        log.log(INFO, "No source for version, return starting_version %r", starting_version)
+        return _sanitize_version(starting_version)
+
     dirty = is_dirty(root=root)
     log.log(INFO, "Is dirty: %r", dirty)
 
-    head_sha = get_sha(root=root)
-    log.log(INFO, "HEAD SHA-256: %r", head_sha)
-
-    full_sha = head_sha if head_sha is not None else ""
-    ccount = count_since(tag_sha, root=root) if tag_sha is not None else None
-    log.log(INFO, "Commits count between HEAD and latest tag: %r", ccount)
-
-    on_tag = head_sha is not None and head_sha == tag_sha and not from_file
-    log.log(INFO, "HEAD is tagged: %r", on_tag)
-
     branch = get_branch(root=root)
     log.log(INFO, "Current branch: %r", branch)
 
@@ -644,6 +612,7 @@ def version_from_git(
         log.log(INFO, "Using template from 'template' option")
         t = template
 
+    full_sha = head_sha if head_sha is not None else ""
     version = _resolve_substitutions(t, sha=full_sha[:8], tag=tag, ccount=ccount, branch=branch, full_sha=full_sha)
     log.log(INFO, "Version number after resolving substitutions: %r", version)
     return _sanitize_version(version)
